# Change Log

## Backwards Compatibility

Minor versions are intended to be backwards compatible. For example, `1.9.0` would be backwards compatible to `1.0.0', but `2.0.0' would not be backwards compatible to `1.9.0'.

## Release Log

### 2020-12-13: 1.0.1

First public release.
